import { Directive, Component, ElementRef, Optional } from "@angular/core";
import { ActionItem, NavigationButton } from "ui/action-bar";
import { isBlank } from "../lang-facade";
import { Page } from "ui/page";
import { View } from "ui/core/view";
import { registerElement, TEMPLATE } from "../element-registry";
let actionBarMeta = {
    skipAddToDom: true,
    insertChild: (parent, child, _atIndex) => {
        const bar = parent;
        const childView = child;
        if (child instanceof NavigationButton) {
            bar.navigationButton = childView;
            childView.parent = bar;
        }
        else if (child instanceof ActionItem) {
            bar.actionItems.addItem(childView);
            childView.parent = bar;
        }
        else if (child.nodeName === TEMPLATE) {
            child.templateParent = parent;
        }
        else if (child.nodeName !== "#text" && child instanceof View) {
            bar.titleView = childView;
        }
    },
    removeChild: (parent, child) => {
        const bar = parent;
        const childView = child;
        if (child instanceof NavigationButton) {
            if (bar.navigationButton === childView) {
                bar.navigationButton = null;
            }
            childView.parent = null;
        }
        else if (child instanceof ActionItem) {
            bar.actionItems.removeItem(childView);
            childView.parent = null;
        }
        else if (child.nodeName !== TEMPLATE && child instanceof View &&
            bar.titleView && bar.titleView === childView) {
            bar.titleView = null;
        }
    },
};
registerElement("ActionBar", () => require("ui/action-bar").ActionBar, actionBarMeta);
registerElement("ActionItem", () => require("ui/action-bar").ActionItem);
registerElement("NavigationButton", () => require("ui/action-bar").NavigationButton);
export let ActionBarComponent = class ActionBarComponent {
    constructor(element, page) {
        this.element = element;
        this.page = page;
        if (isBlank(this.page.actionBarHidden)) {
            this.page.actionBarHidden = false;
        }
        this.page.actionBar = this.element.nativeElement;
        this.page.actionBar.update();
    }
};
ActionBarComponent = __decorate([
    Component({
        selector: "ActionBar",
        template: "<ng-content></ng-content>"
    }), 
    __metadata('design:paramtypes', [ElementRef, Page])
], ActionBarComponent);
export let ActionBarScope = class ActionBarScope {
    constructor(page) {
        this.page = page;
    }
    onNavButtonInit(navBtn) {
        this.page.actionBar.navigationButton = navBtn.element.nativeElement;
    }
    onNavButtonDestroy(navBtn) {
        const nav = navBtn.element.nativeElement;
        if (nav && this.page.actionBar.navigationButton === nav) {
            this.page.actionBar.navigationButton = null;
        }
    }
    onActionInit(item) {
        this.page.actionBar.actionItems.addItem(item.element.nativeElement);
    }
    onActionDestroy(item) {
        this.page.actionBar.actionItems.removeItem(item.element.nativeElement);
    }
};
ActionBarScope = __decorate([
    Component({
        selector: "ActionBarExtension",
        template: ""
    }), 
    __metadata('design:paramtypes', [Page])
], ActionBarScope);
export let ActionItemDirective = class ActionItemDirective {
    constructor(element, ownerScope) {
        this.element = element;
        this.ownerScope = ownerScope;
        if (this.ownerScope) {
            this.ownerScope.onActionInit(this);
        }
    }
    ngOnDestroy() {
        if (this.ownerScope) {
            this.ownerScope.onActionDestroy(this);
        }
    }
};
ActionItemDirective = __decorate([
    Directive({
        selector: "ActionItem" // tslint:disable-line:directive-selector
    }),
    __param(1, Optional()), 
    __metadata('design:paramtypes', [ElementRef, ActionBarScope])
], ActionItemDirective);
export let NavigationButtonDirective = class NavigationButtonDirective {
    constructor(element, ownerScope) {
        this.element = element;
        this.ownerScope = ownerScope;
        if (this.ownerScope) {
            this.ownerScope.onNavButtonInit(this);
        }
    }
    ngOnDestroy() {
        if (this.ownerScope) {
            this.ownerScope.onNavButtonDestroy(this);
        }
    }
};
NavigationButtonDirective = __decorate([
    Directive({
        selector: "NavigationButton" // tslint:disable-line:directive-selector
    }),
    __param(1, Optional()), 
    __metadata('design:paramtypes', [ElementRef, ActionBarScope])
], NavigationButtonDirective);
//# sourceMappingURL=action-bar.js.map