import { Injectable, Compiler } from "@angular/core";
import { path, knownFolders } from "file-system";
const SEPARATOR = "#";
const FACTORY_CLASS_SUFFIX = "NgFactory";
const FACTORY_PATH_SUFFIX = ".ngfactory";
export let NSModuleFactoryLoader = class NSModuleFactoryLoader {
    constructor(compiler) {
        this.compiler = compiler;
        this.offlineMode = compiler instanceof Compiler;
    }
    load(path) {
        let { modulePath, exportName } = this.splitPath(path);
        if (this.offlineMode) {
            return this.loadFactory(modulePath, exportName);
        }
        else {
            return this.loadAndCompile(modulePath, exportName);
        }
    }
    loadFactory(modulePath, exportName) {
        modulePath = factoryModulePath(modulePath);
        exportName = factoryExportName(exportName);
        return System.import(modulePath)
            .then((module) => module[exportName])
            .then((factory) => checkNotEmpty(factory, modulePath, exportName));
    }
    loadAndCompile(modulePath, exportName) {
        modulePath = getAbsolutePath(modulePath);
        let loadedModule = require(modulePath)[exportName];
        checkNotEmpty(loadedModule, modulePath, exportName);
        return Promise.resolve(this.compiler.compileModuleAsync(loadedModule));
    }
    splitPath(path) {
        let [modulePath, exportName] = path.split(SEPARATOR);
        if (typeof exportName === "undefined") {
            exportName = "default";
        }
        return { modulePath, exportName };
    }
};
NSModuleFactoryLoader = __decorate([
    Injectable(), 
    __metadata('design:paramtypes', [Compiler])
], NSModuleFactoryLoader);
function getAbsolutePath(relativePath) {
    return path.normalize(path.join(knownFolders.currentApp().path, relativePath));
}
function factoryModulePath(modulePath) {
    return `${modulePath}${FACTORY_PATH_SUFFIX}`;
}
function factoryExportName(exportName) {
    return exportName === "default" ?
        exportName :
        `${exportName}${FACTORY_CLASS_SUFFIX}`;
}
function checkNotEmpty(value, modulePath, exportName) {
    if (!value) {
        throw new Error(`Cannot find '${exportName}' in '${modulePath}'`);
    }
    return value;
}
//# sourceMappingURL=ns-module-factory-loader.js.map