export function generateValueAccessorSelector(...tagNames) {
    const tags = [];
    tagNames.forEach(tagName => {
        tags.push(tagName); // regular tag
        tags.push(tagName.charAt(0).toLowerCase() + tagName.slice(1)); // lowercase first char
        tags.push(tagName.split(/(?=[A-Z])/).join("-").toLowerCase()); // kebab case
    });
    const selectors = [];
    for (const tag of tags) {
        for (const directive of ["ngModel", "formControlName"]) {
            selectors.push(`${tag}[${directive}]`);
        }
    }
    return selectors.join(", ");
}
export class BaseValueAccessor {
    constructor(view) {
        this.view = view;
        this.onChange = (_) => { };
        this.pendingChangeNotification = 0;
    }
    registerOnChange(fn) {
        this.onChange = (arg) => {
            if (this.pendingChangeNotification) {
                clearTimeout(this.pendingChangeNotification);
            }
            this.pendingChangeNotification = setTimeout(() => {
                this.pendingChangeNotification = 0;
                fn(arg);
            }, 20);
        };
    }
    writeValue(_) {
        //
    }
    registerOnTouched(_) {
        //
    }
}
//# sourceMappingURL=base-value-accessor.js.map