import { Directive, ElementRef, forwardRef, HostListener } from "@angular/core";
import { NG_VALUE_ACCESSOR } from "@angular/forms";
import { isBlank, isDate } from "../lang-facade";
import { BaseValueAccessor, generateValueAccessorSelector } from "./base-value-accessor";
const TIME_VALUE_ACCESSOR = { provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => TimeValueAccessor), multi: true };
/**
 * The accessor for setting a time and listening to changes that is used by the
 * {@link NgModel} directives.
 *
 *  ### Example
 *  ```
 *  <TimePicker [(ngModel)]="model.test">
 *  ```
 */
export let TimeValueAccessor = class TimeValueAccessor extends BaseValueAccessor {
    constructor(elementRef) {
        super(elementRef.nativeElement);
        this.onTouched = () => { };
    }
    timeChangeListener(event) {
        this.onChange(event.value);
    }
    writeValue(value) {
        let normalizedValue = isBlank(value) ? new Date() : value;
        if (!isDate(normalizedValue)) {
            if (typeof normalizedValue === "string") {
                normalizedValue = new Date(normalizedValue);
            }
            else if (typeof normalizedValue === "number") {
                normalizedValue = new Date(normalizedValue);
            }
            if (!isDate(normalizedValue)) {
                normalizedValue = new Date();
            }
        }
        this.view.time = normalizedValue;
    }
    registerOnTouched(fn) { this.onTouched = fn; }
};
__decorate([
    // tslint:disable-line:directive-class-suffix
    HostListener("timeChange", ["$event"]), 
    __metadata('design:type', Function), 
    __metadata('design:paramtypes', [Object]), 
    __metadata('design:returntype', void 0)
], TimeValueAccessor.prototype, "timeChangeListener", null);
TimeValueAccessor = __decorate([
    Directive({
        selector: generateValueAccessorSelector("TimePicker"),
        providers: [TIME_VALUE_ACCESSOR]
    }), 
    __metadata('design:paramtypes', [ElementRef])
], TimeValueAccessor);
//# sourceMappingURL=time-value-accessor.js.map